@@ -1,11 +1,11 @@
 import sys
-huPDt=object
-huPDa=staticmethod
-huPDY=False
-huPDI=Exception
-huPDL=None
-huPDn=input
-huPDR=list
+teCAz=object
+teCAy=staticmethod
+teCAf=False
+teCAs=Exception
+teCAJ=None
+teCAT=input
+teCAw=list
 import json
 import logging
 import getpass
@@ -13,29 +13,29 @@ from localstack.config import CONFIG_FILE_PATH,load_config_file
 from localstack.constants import API_ENDPOINT
 from localstack.utils.common import to_str,safe_requests,save_file,load_file
 LOG=logging.getLogger(__name__)
-class AuthProvider(huPDt):
- @huPDa
+class AuthProvider(teCAz):
+ @teCAy
  def name():
   raise
  def get_or_create_token(self,username,password,headers):
   pass
  def get_user_for_token(self,token):
   pass
- @huPDa
+ @teCAy
  def providers():
   return{c.name():c for c in AuthProvider.__subclasses__()}
- @huPDa
- def get(provider,raise_error=huPDY):
+ @teCAy
+ def get(provider,raise_error=teCAf):
   provider_class=AuthProvider.providers().get(provider)
   if not provider_class:
    msg='Unable to find auth provider class "%s"'%provider
    LOG.warning(msg)
    if raise_error:
-    raise huPDI(msg)
-   return huPDL
+    raise teCAs(msg)
+   return teCAJ
   return provider_class()
 class AuthProviderInternal(AuthProvider):
- @huPDa
+ @teCAy
  def name():
   return 'internal'
  def get_or_create_token(self,username,password,headers):
@@ -46,28 +46,28 @@ class AuthProviderInternal(AuthProvider):
   try:
    result=json.loads(to_str(response.content or '{}'))
    return result['token']
-  except huPDI:
+  except teCAs:
    pass
  def read_credentials(self,username):
   print('Please provide your login credentials below')
   if not username:
    sys.stdout.write('Username: ')
    sys.stdout.flush()
-   username=huPDn()
+   username=teCAT()
   password=getpass.getpass()
   return username,password,{}
  def get_user_for_token(self,token):
-  raise huPDI('Not implemented')
-def login(provider,username=huPDL):
+  raise teCAs('Not implemented')
+def login(provider,username=teCAJ):
  auth_provider=AuthProvider.get(provider)
  if not auth_provider:
-  providers=huPDR(AuthProvider.providers().keys())
-  raise huPDI('Unknown provider "%s", should be one of %s'%(provider,providers))
+  providers=teCAw(AuthProvider.providers().keys())
+  raise teCAs('Unknown provider "%s", should be one of %s'%(provider,providers))
  username,password,headers=auth_provider.read_credentials(username)
  print('Verifying credentials ... (this may take a few moments)')
  token=auth_provider.get_or_create_token(username,password,headers)
  if not token:
-  raise huPDI('Unable to verify login credentials - please try again')
+  raise teCAs('Unable to verify login credentials - please try again')
  configs=load_config_file()
  configs['login']={'provider':provider,'username':username,'token':token}
  save_file(CONFIG_FILE_PATH,json.dumps(configs))
