@@ -1,11 +1,11 @@
 import os
-IasXP=Exception
-IasXD=any
-IasXJ=str
-IasXL=None
-IasXm=False
-IasXt=bool
-IasXC=True
+uMtXE=Exception
+uMtXK=any
+uMtXB=str
+uMtXs=None
+uMtXI=False
+uMtXg=bool
+uMtXk=True
 import logging
 from localstack import config as localstack_config
 from localstack.utils import common
@@ -29,14 +29,14 @@ def register_localstack_plugins():
   try:
    from localstack_ext.services import dns_server
    dns_server.setup_network_configuration()
-  except IasXP:
+  except uMtXE:
    return
   if is_infra_process:
    load_plugin_files()
   try:
    if is_api_key_configured and not is_infra_process and is_api_enabled('ec2'):
     local_daemon.start_in_background()
-  except IasXP as e:
+  except uMtXE as e:
    LOG.warning('Unable to start local daemon process: %s'%e)
   if is_api_key_configured:
    if os.environ.get('EDGE_PORT')and not localstack_config.EDGE_PORT_HTTP:
@@ -67,7 +67,7 @@ def register_localstack_plugins():
    docker_flags+=['-p {a}:{p}:{p}'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
   if not common.is_port_open(dns_server.DNS_PORT,protocols='udp'):
    docker_flags+=['-p {a}:{p}:{p}/udp'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
- if IasXD([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
+ if uMtXK([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
   docker_flags+=['-p {start}-{end}:{start}-{end}'.format(start=config_ext.SERVICE_INSTANCES_PORTS_START,end=config_ext.SERVICE_INSTANCES_PORTS_END)]
  if is_api_enabled('eks'):
   kube_config=os.path.expanduser('~/.kube/config')
@@ -86,6 +86,7 @@ def load_plugin_files():
   from localstack_ext.services.amplify import amplify_starter
   from localstack_ext.services.applicationautoscaling import(applicationautoscaling_starter,applicationautoscaling_listener)
   from localstack_ext.services.appsync import appsync_starter
+  from localstack_ext.services.autoscaling import autoscaling_starter
   from localstack_ext.services.azure import azure_starter
   from localstack_ext.services.apigateway import apigateway_extended
   from localstack_ext.services.athena import athena_starter
@@ -96,12 +97,14 @@ def load_plugin_files():
   from localstack_ext.services.cloudtrail import cloudtrail_starter
   from localstack_ext.services.codecommit import codecommit_starter,codecommit_listener
   from localstack_ext.services.cognito import cognito_starter,cognito_listener
+  from localstack_ext.services.costexplorer import costexplorer_starter
   from localstack_ext.services.docdb import docdb_api
   from localstack_ext.services.dynamodb import dynamodb_extended
   from localstack_ext.services.ecr import ecr_starter,ecr_listener
   from localstack_ext.services.ecs import ecs_starter,ecs_listener
   from localstack_ext.services.eks import eks_starter
   from localstack_ext.services.elasticache import elasticache_starter
+  from localstack_ext.services.elasticbeanstalk import elasticbeanstalk_starter
   from localstack_ext.services.elb import elb_starter,elb_listener
   from localstack_ext.services.emr import emr_starter,emr_listener
   from localstack_ext.services.events import events_extended
@@ -139,6 +142,7 @@ def load_plugin_files():
   register_plugin(Plugin('application-autoscaling',start=applicationautoscaling_starter.start_applicationautoscaling,listener=applicationautoscaling_listener.UPDATE_APPLICATION_AUTOSCALING))
   register_plugin(Plugin('appsync',start=appsync_starter.start_appsync))
   register_plugin(Plugin('athena',start=athena_starter.start_athena))
+  register_plugin(Plugin('autoscaling',start=autoscaling_starter.start_autoscaling))
   register_plugin(Plugin('azure',start=azure_starter.start_azure))
   register_plugin(Plugin('batch',start=batch_starter.start_batch,listener=batch_listener.UPDATE_BATCH))
   register_plugin(Plugin('cloudfront',start=cloudfront_starter.start_cloudfront))
@@ -146,8 +150,10 @@ def load_plugin_files():
   register_plugin(Plugin('codecommit',start=codecommit_starter.start_codecommit,listener=codecommit_listener.UPDATE_CODECOMMIT))
   register_plugin(Plugin('cognito-identity',start=cognito_starter.start_cognito_identity,listener=cognito_listener.UPDATE_COGNITO_IDENTITY))
   register_plugin(Plugin('cognito-idp',start=cognito_starter.start_cognito_idp,listener=cognito_listener.UPDATE_COGNITO))
+  register_plugin(Plugin('ce',start=costexplorer_starter.start_costexplorer))
   register_plugin(Plugin('docdb',start=docdb_api.start_docdb))
   register_plugin(Plugin('elasticache',start=elasticache_starter.start_elasticache))
+  register_plugin(Plugin('elasticbeanstalk',start=elasticbeanstalk_starter.start_elasticbeanstalk))
   register_plugin(Plugin('elb',start=elb_starter.start_elb,listener=elb_listener.UPDATE_ELB))
   register_plugin(Plugin('elbv2',start=elb_starter.start_elbv2,listener=elb_listener.UPDATE_ELB))
   register_plugin(Plugin('ecr',start=ecr_starter.start_ecr,listener=ecr_listener.UPDATE_ECR))
@@ -191,24 +197,24 @@ def load_plugin_files():
   aws_utils.patch_aws_stack()
   edge.patch_start_edge()
   patch_start_infra()
- except IasXP as e:
-  if 'No module named' not in IasXJ(e):
+ except uMtXE as e:
+  if 'No module named' not in uMtXB(e):
    print('ERROR: %s'%e)
 def patch_start_infra():
  from localstack.services import infra
  try:
   from localstack_ext.utils.aws.metadata_service import start_metadata_service
- except IasXP:
-  start_metadata_service=IasXL
+ except uMtXE:
+  start_metadata_service=uMtXs
  def do_start_infra(asynchronous,apis,is_in_docker,*args,**kwargs):
   if common.in_docker():
    try:
     start_metadata_service and start_metadata_service()
-   except IasXP:
+   except uMtXE:
     pass
   enforce_before=config_ext.ENFORCE_IAM
   try:
-   config_ext.ENFORCE_IAM=IasXm
+   config_ext.ENFORCE_IAM=uMtXI
    return do_start_infra_orig(asynchronous,apis,is_in_docker,*args,**kwargs)
   finally:
    config_ext.ENFORCE_IAM=enforce_before
@@ -226,14 +232,14 @@ def _setup_logging():
  logging.getLogger('hpack').setLevel(logging.INFO)
  logging.getLogger('jnius.reflect').setLevel(logging.INFO)
  logging.getLogger('dulwich').setLevel(logging.ERROR)
- logging.getLogger('postgresql_proxy').setLevel(logging.INFO)
+ logging.getLogger('postgresql_proxy').setLevel(logging.WARNING)
  logging.getLogger('intercept').setLevel(logging.WARNING)
  logging.getLogger('root').setLevel(logging.WARNING)
  logging.getLogger('').setLevel(logging.WARNING)
 def api_key_configured():
- return IasXt(os.environ.get('LOCALSTACK_API_KEY'))
+ return uMtXg(os.environ.get('LOCALSTACK_API_KEY'))
 def register_localstack_commands():
  if api_key_configured():
   cli.register_commands()
- return IasXC
+ return uMtXk
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
